/*--------------------------------------------------------------------------+
|                                                                          |
| Copyright 2022 fortiss GmbH           						           |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.ui.util;

import static java.util.Arrays.asList;
import static java.util.stream.Collectors.toList;
import static org.fortiss.variability.util.VariabilityUtils.PRESENCE_CONDITIONS_KEYWORDS;
import static org.fortiss.variability.util.VariabilityUtilsInternal.getAllElementsFromSameContainmentTree;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.text.link.ProposalPosition;
import org.fortiss.tooling.base.ui.fieldassist.ProposalProviderBase;
import org.fortiss.variability.model.presence.ILiteralReferencable;
import org.fortiss.variability.model.presence.PresenceCondition;

/**
 * {@link ProposalPosition} for {@link PresenceCondition}.
 * 
 * @author bayha
 */
public class PresenceConditionProposalProvider extends ProposalProviderBase {

	/** An {@link EObject} in the project to give the scope for searching. */
	EObject context;

	/**
	 * Constructor.
	 * 
	 * @param context
	 *            An {@link EObject} in the project to give the scope for
	 *            searching.
	 */
	public PresenceConditionProposalProvider(EObject context) {
		super();
		this.context = context;
	}

	/** {@inheritDoc} */
	@Override
	public String[] getProposals(String currentWord) {
		if(context == null) {
			return new String[0];
		}
		List<ILiteralReferencable> literals =
				getAllElementsFromSameContainmentTree(context, ILiteralReferencable.class);

		List<String> stringLiterals = literals.stream().map(l -> l.getName()).collect(toList());

		final String[] keywords = PRESENCE_CONDITIONS_KEYWORDS.split("\\|");
		stringLiterals.addAll(asList(keywords));

		List<String> proposals =
				stringLiterals.stream().filter(n -> n.startsWith(currentWord)).collect(toList());

		return proposals.toArray(new String[proposals.size()]);
	}
}
